% La fonction "Poisson_ponct" simule les instants de sauts sur [0,"T"].
function Poisson_ponct (T)
% On initialise les paramètres globaux à l'aide de la fonction
% "init_param".
init_param;
% "sauts" va contenir les instants de saut.
sauts = [];
% "t" est l'instant courant, initialement 0 (par contre, 0 n'est pas un
% instant de saut !).
t = 0;
% "nbsauts" compte le nombre de sauts qui ont eu lieu.
nbsauts = 0;
% Comme la sortie de la boucle n'est pas au même endroit que l'entrée, on
% écrit la boucle sous la forme « while true »
while true
    % On calcule le temps d'attente à partir de la sous-routine "attente".
    t_attente = attente;
    % On met à jour t au prochain instant de saut. À cause de la propriété
    % de perte de mémoire de l'exponentielle, ça ne change rien de savoir
    % qu'on est parti du temps 0 ou qu'on a repris dès le dernier saut...
    t = t + t_attente;
    % Si on a dépassé T, on sort de la boucle, et il n'y a rien à écrire
    % dans "sauts".
    if t > T
        break
    end
    % On met à jour le nombre de sauts, ainsi que le vecteur des instants
    % de sauts. Notez que MATLAB râle quand on met à jour le vecteur des
    % sauts, car on change la taille du vecteur, ce qui induit des
    % opérations chronophage de déplacement dans la mémoire de
    % l'ordinateur...
    nbsauts = nbsauts + 1;
    sauts(nbsauts) = t;
end
% Comme MATLAB veut aussi un vecteur d'ordonnées à plotter, on prépare un
% tel vecteur ne contenant que des zéros, de même taille que le vecteur des
% sauts.
Y = zeros (1, nbsauts);
% On trace le graphique.
plot (sauts, Y, '.');
% Titre de la figure.
title ('Instants de sauts');
return
end
