% La fonction "Poisson_ponct_alt" fait la même chose que "Poisson_ponct",
% mais d'une façon plus générique où on n'a pas à changer la taille du
% vecteur à chaque fois.
function Poisson_ponct_alt (T)
init_param;
global LAMBDA
% Cette fois-ci je prévois à l'avance d'allouer de la mémoire pour les
% instants de sauts. Comme je sais qu'il y aura (LAMBDA*T) sauts en
% moyenne, je prévois, disons, le double de mémoire (arrondi par excès). Je
% mémorise cette taille dans "taille_vecteur", afin de savoir quand est-ce
% que j'aurai éventuellement épuisé l'espace disponible.
taille_vecteur = ceil (LAMBDA * T);
sauts = zeros (1, taille_vecteur);
t = 0;
nbsauts = 0;
while true
    t_attente = attente;
    t = t + t_attente;
    if t > T
        break
    end
    % Pour mettre à jour le vecteur des instants de sauts, il y a deux cas
    % : soit (le cas le plus fréquent) on a encore de la place, soit on
    % déborde de la taille de vecteur "sauts". Dans le premier cas, on
    % écrit notre instant de saut normalement dans "sauts". Dans le second
    % cas, par contre, il faut d'abord remplacer "sauts" par un vecteur
    % plus grand (disons deux fois plus grand), dans lequel on aura
    % transféré les données déjà écrites, avant de rentrer notre nouvelle
    % donnée dans ce vecteur agrandi. Notez qu'en fait cette opération
    % n'est pas réellement nécessaire sous MATLAB, qui y procèderait
    % automatiquement ; mais sous d'autres langages ce ne serait pas le
    % cas, et il est donc utile de savoir le faire à la main...
    nbsauts = nbsauts + 1;
    if nbsauts > taille_vecteur
        % On sauvegarde d'abord le vecteur "sauts" dans une copie.
        copie_vecteur = sauts;
        % On remplace maintenant "sauts" par un vecteur nul de taille
        % "nouvelle_taille_vecteur", en l'occurrence le double de
        % l'ancienne.
        nouvelle_taille_vecteur = 2 * taille_vecteur;
        sauts = zeros (1, nouvelle_taille_vecteur);
        % On recopie les anciennes données de "sauts" dans le nouveau
        % vecteur.
        sauts(1: taille_vecteur) = copie_vecteur;
        % On met à jour "taille_vecteur".
        taille_vecteur = nouvelle_taille_vecteur;
    end
    sauts(nbsauts) = t;
end
% Attention, maintenant il ne faut pas plotter les zéros qui terminent
% notre vecteur "sauts"... On appelle "X" la partie réellement utile du
% vecteur.
X = sauts(1: nbsauts);
Y = zeros (1, nbsauts);
plot (X, Y, '.');
title ('Instants de sauts');
return
end
